@@ -6,7 +6,7 @@ use feature 'signatures';
 no warnings 'experimental::signatures';
 
 use vars '$VERSION';
-$VERSION = '0.07';
+$VERSION = '0.08';
 
 =head1 NAME
 
@@ -75,7 +75,7 @@ sub _get_extension( $e=undef ) {
 }
 
 sub _globmatch( $target, $glob ) {
-    $glob =~ s![.]!\\.!g;
+    $glob =~ s!([.+\\])!\\$1!g;
     $glob =~ s!\*!.*!g;
     $target =~ /\A$glob\z/;
 }
